@@ -14,7 +14,7 @@ import numpy
 import os
 import time
 
-import myPythonLibrary    as mypy
+import myPythonLibrary as mypy
 
 import dolfin_warp as dwarp
 
@@ -103,7 +103,7 @@ class ReducedKinematicsNewtonNonlinearSolver(RelaxationNonlinearSolver):
             # relaxation
             self.compute_relax()
             self.reduced_ddisp *= self.relax
-            self.problem.dU.vector()[:] *= self.relax
+            self.problem.dU.vector().get_local()[:] *= self.relax
             self.problem.dU_norm *= abs(self.relax)
 
             # solution update
