@@ -2,20 +2,13 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
-import dolfin
-import glob
-import math
 import numpy
-import os
-import random
 import vtk
 
 import myPythonLibrary    as mypy
@@ -32,18 +25,17 @@ def compute_downsampled_images(
         images_ext="vti",
         keep_resolution=0,
         write_temp_images=0,
-        suffix="",
+        suffix=None,
         verbose=0):
 
     mypy.my_print(verbose, "*** compute_downsampled_images ***")
 
-    images_filenames = glob.glob(images_folder+"/"+images_basename+"_[0-9]*"+"."+images_ext)
-    images_nframes = len(images_filenames)
-    images_zfill = len(images_filenames[0].rsplit("_",1)[-1].split(".",1)[0])
+    images_series = dwarp.ImagesSeries(
+        folder=images_folder,
+        basename=images_basename,
+        ext=images_ext)
 
-    image = myvtk.readImage(
-        filename=images_folder+"/"+images_basename+"_"+str(0).zfill(images_zfill)+"."+images_ext,
-        verbose=0)
+    image = images_series.get_image(k_frame=0)
     images_ndim = myvtk.getImageDimensionality(
         image=image,
         verbose=0)
@@ -87,10 +79,7 @@ def compute_downsampled_images(
         writer_fft.SetInputData(fft.GetOutput())
 
     if (keep_resolution):
-        image_filename = images_folder+"/"+images_basename+"_"+str(0).zfill(images_zfill)+"."+images_ext
-        mask_image = myvtk.readImage(
-            filename=image_filename,
-            verbose=0)
+        mask_image = images_series.get_image(k_frame=0)
         mask_scalars = myvtk.createDoubleArray(
             name="ImageScalars",
             n_components=2,
@@ -113,7 +102,7 @@ def compute_downsampled_images(
         if (write_temp_images):
             myvtk.writeImage(
                 image=mask_image,
-                filename=images_folder+"/"+images_basename+"_mask"+"."+images_ext,
+                filename=images_series.get_image_filename(k_frame=None, suffix="mask"),
                 verbose=0)
 
         mult = vtk.vtkImageMathematics()
@@ -125,8 +114,6 @@ def compute_downsampled_images(
             writer_mul = writer_type()
             writer_mul.SetInputData(mult.GetOutput())
     else:
-        images_downsampled_npoints = numpy.prod(images_downsampled_dimensions)
-        mypy.my_print(verbose, "images_downsampled_npoints = "+str(images_downsampled_npoints))
         downsampling_factors = list(numpy.divide(images_dimensions, images_downsampled_dimensions))
         mypy.my_print(verbose, "downsampling_factors = "+str(downsampling_factors))
         downsampling_factor = numpy.prod(downsampling_factors)
@@ -136,17 +123,13 @@ def compute_downsampled_images(
         images_downsampled_spacing = list(numpy.multiply(images_spacing, downsampling_factors))
         mypy.my_print(verbose, "images_downsampled_spacing = "+str(images_downsampled_spacing))
 
-        image_downsampled = vtk.vtkImageData()
-        image_downsampled.SetDimensions(images_downsampled_dimensions)
-        image_downsampled.SetOrigin(images_downsampled_origin)
-        image_downsampled.SetSpacing(images_downsampled_spacing)
-
-        image_downsampled_scalars = myvtk.createDoubleArray(
-            name="ImageScalars",
-            n_components=2,
-            n_tuples=images_downsampled_npoints,
-            verbose=0)
-        image_downsampled.GetPointData().SetScalars(image_downsampled_scalars)
+        image_downsampled = myvtk.createImage(
+            origin=images_downsampled_origin,
+            spacing=images_downsampled_spacing,
+            dimensions=images_downsampled_dimensions,
+            array_name="ImageScalars",
+            array_n_components=2)
+        image_downsampled_scalars = image.GetPointData().GetScalars()
         I = numpy.empty(2)
 
         if (write_temp_images):
@@ -169,22 +152,22 @@ def compute_downsampled_images(
     writer = writer_type()
     writer.SetInputData(extract.GetOutput())
 
-    for k_frame in range(images_nframes):
+    for k_frame in range(images_series.n_frames):
         mypy.my_print(verbose, "k_frame = "+str(k_frame))
 
-        reader.SetFileName(images_folder+"/"+images_basename+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext)
+        reader.SetFileName(images_series.get_image_filename(k_frame=k_frame))
         reader.Update()
 
         fft.Update()
         if (write_temp_images):
-            writer_fft.SetFileName(images_folder+"/"+images_basename+"_fft"+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext)
+            writer_fft.SetFileName(images_series.get_image_filename(k_frame=k_frame, suffix="fft"))
             writer_fft.Write()
 
         if (keep_resolution):
 
             mult.Update()
             if (write_temp_images):
-                writer_mul.SetFileName(images_folder+"/"+images_basename+"_mul"+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext)
+                writer_mul.SetFileName(images_series.get_image_filename(k_frame=k_frame, suffix="mul"))
                 writer_mul.Write()
 
         else:
@@ -205,12 +188,12 @@ def compute_downsampled_images(
             image_downsampled.Modified()
 
             if (write_temp_images):
-                writer_sel.SetFileName(images_folder+"/"+images_basename+"_sel"+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext)
+                writer_sel.SetFileName(images_series.get_image_filename(k_frame=k_frame, suffix="sel"))
                 writer_sel.Write()
 
         rfft.Update()
 
         extract.Update()
 
-        writer.SetFileName(images_folder+"/"+images_basename+("_"+suffix)*(suffix!="")+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext)
+        writer.SetFileName(images_series.get_image_filename(k_frame=k_frame, suffix=suffix))
         writer.Write()
