@@ -2,23 +2,19 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
-import dolfin
 import glob
 import math
 import numpy
 import scipy
-from scipy.interpolate import InterpolatedUnivariateSpline # MG20200616: Is that needed?
+import scipy.interpolate
 import vtk
 
-import myPythonLibrary    as mypy
 import myVTKPythonLibrary as myvtk
 import vtkpython_cbl      as cbl
 
@@ -41,6 +37,8 @@ def compute_strains(
         ref_mesh_ext="vtk",
         CYL_or_PPS="PPS",
         remove_boundary_layer=1,
+        threshold_value=0.5,
+        threshold_by_upper_or_lower="lower",
         in_place=1,
         write_strains=1,
         temporal_offset=0,
@@ -107,49 +105,41 @@ def compute_strains(
         n_part_ids = 0
         n_sector_ids = 0
 
-    working_filenames = glob.glob(working_folder+"/"+working_basename+"_[0-9]*."+working_ext)
-    assert (len(working_filenames) > 0), "There is no working file ("+working_folder+"/"+working_basename+"_[0-9]*."+working_ext+"). Aborting."
-
-    working_zfill = len(working_filenames[0].rsplit("_",1)[-1].split(".")[0])
-    if (verbose): print("working_zfill = " + str(working_zfill))
-
-    n_frames = len(working_filenames)
-    if (verbose): print("n_frames = " + str(n_frames))
+    working_series = dwarp.MeshesSeries(
+        folder=working_folder,
+        basename=working_basename,
+        ext=working_ext)
+    if (verbose): print("n_frames = " + str(working_series.n_frames))
+    if (verbose): print("zfill = " + str(working_series.zfill))
 
     if (write_strains):
         strain_file = open(working_folder+"/"+working_basename+"-strains.dat", "w")
-        strain_file.write("#t Err_avg Err_std Ecc_avg Ecc_std Ell_avg Ell_std Erc_avg Erc_std Erl_avg Erl_std Ecl_avg Ecl_std\n")
+        strain_file.write("#k_frame Err_avg Err_std Ecc_avg Ecc_std Ell_avg Ell_std Erc_avg Erc_std Erl_avg Erl_std Ecl_avg Ecl_std\n")
 
     if (write_strains_vs_radius):
         strains_vs_radius_file = open(working_folder+"/"+working_basename+"-strains_vs_radius.dat", "w")
-        strains_vs_radius_file.write("#t rr Err Ecc Ell Erc Erl Ecl\n")
+        strains_vs_radius_file.write("#k_frame rr Err Ecc Ell Erc Erl Ecl\n")
 
     if (write_binned_strains_vs_radius):
         binned_strains_vs_radius_file = open(working_folder+"/"+working_basename+"-binned_strains_vs_radius.dat", "w")
-        binned_strains_vs_radius_file.write("#t rr Err Ecc Ell Erc Erl Ecl\n")
+        binned_strains_vs_radius_file.write("#k_frame rr Err Ecc Ell Erc Erl Ecl\n")
 
     if (write_twist_vs_height):
         twist_vs_height_file = open(working_folder+"/"+working_basename+"-twist_vs_height.dat", "w")
-        twist_vs_height_file.write("#t z beta\n")
+        twist_vs_height_file.write("#k_frame z beta\n")
 
     if (ref_frame is not None):
-        mesh0_filename = working_folder+"/"+working_basename+"_"+str(ref_frame).zfill(working_zfill)+"."+working_ext
-        mesh0 = myvtk.readUGrid(
-            filename=mesh0_filename,
-            verbose=verbose)
+        mesh0 = working_series.get_mesh(k_frame=ref_frame)
         myvtk.addDeformationGradients(
             mesh=mesh0,
             disp_array_name=disp_array_name,
             verbose=verbose)
         farray_F0 = mesh0.GetCellData().GetArray(defo_grad_array_name)
 
-    for k_frame in range(n_frames):
+    for k_frame in range(working_series.n_frames):
         print("k_frame = "+str(k_frame))
 
-        mesh_filename = working_folder+"/"+working_basename+"_"+str(k_frame).zfill(working_zfill)+"."+working_ext
-        mesh = myvtk.readUGrid(
-            filename=mesh_filename,
-            verbose=verbose)
+        mesh = working_series.get_mesh(k_frame=k_frame)
         n_points = mesh.GetNumberOfPoints()
         n_cells = mesh.GetNumberOfCells()
         if (ref_mesh is not None):
@@ -188,18 +178,16 @@ def compute_strains(
             strain_array_name=strain_array_name,
             mesh_w_local_basis=ref_mesh,
             verbose=verbose)
-        ### 20210601 Modif CL
         myvtk.addJacobiansFromDeformationGradients(
-                mesh=mesh,
-                defo_grad_array_name=defo_grad_array_name,
-                jacobian_array_name=jacobian_array_name,
-                verbose=verbose)
+            mesh=mesh,
+            defo_grad_array_name=defo_grad_array_name,
+            jacobian_array_name=jacobian_array_name,
+            verbose=verbose)
         myvtk.addEquivDeviatoricStrainsFromDeformationGradients(
-                mesh=mesh,
-                defo_grad_array_name=defo_grad_array_name,
-                equiv_dev_strain_array_basename=equiv_dev_strain_array_basename,
-                verbose=verbose)
-        ###
+            mesh=mesh,
+            defo_grad_array_name=defo_grad_array_name,
+            equiv_dev_strain_array_basename=equiv_dev_strain_array_basename,
+            verbose=verbose)
         if (ref_mesh is not None):
             if  (iarray_ref_part_id is not None)\
             and (remove_boundary_layer         ):
@@ -207,8 +195,8 @@ def compute_strains(
                     ugrid=mesh,
                     field_support="cells",
                     field_name="part_id",
-                    threshold_value=0.5,
-                    threshold_by_upper_or_lower="lower")
+                    threshold_value=threshold_value,
+                    threshold_by_upper_or_lower=threshold_by_upper_or_lower)
                 n_points = mesh.GetNumberOfPoints()
                 n_cells = mesh.GetNumberOfCells()
                 n_part_ids = 0
@@ -216,7 +204,7 @@ def compute_strains(
                     iarray_sector_id = mesh.GetCellData().GetArray("sector_id")
             else:
                 iarray_sector_id = iarray_ref_sector_id
-        mesh_filename = working_folder+"/"+working_basename+("-wStrains")*(not in_place)+"_"+str(k_frame).zfill(working_zfill)+"."+working_ext
+        mesh_filename = working_folder+"/"+working_basename+("-wStrains")*(not in_place)+"_"+str(k_frame).zfill(working_series.zfill)+"."+working_ext
         myvtk.writeUGrid(
             ugrid=mesh,
             filename=mesh_filename,
@@ -322,22 +310,22 @@ def compute_strains(
                     verbose=verbose-1)
 
                 if (twist_vs_height_interpolation == "piecewiseLinear"):
-                    warped_sector_centroids_x = InterpolatedUnivariateSpline(
+                    warped_sector_centroids_x = scipy.interpolate.InterpolatedUnivariateSpline(
                         numpy.flip(warped_sector_centroids[:,2]),
                         numpy.flip(warped_sector_centroids[:,0]),
                         k=1,
                         ext=0)
-                    warped_sector_centroids_y =  InterpolatedUnivariateSpline(
+                    warped_sector_centroids_y = scipy.interpolate.InterpolatedUnivariateSpline(
                         numpy.flip(warped_sector_centroids[:,2]),
                         numpy.flip(warped_sector_centroids[:,1]),
                         k=1,
                         ext=0)
-                    ref_sector_centroids_x = InterpolatedUnivariateSpline(
+                    ref_sector_centroids_x = scipy.interpolate.InterpolatedUnivariateSpline(
                         numpy.flip(ref_sector_centroids[:,2]),
                         numpy.flip(ref_sector_centroids[:,0]),
                         k=1,
                         ext=0)
-                    ref_sector_centroids_y = InterpolatedUnivariateSpline(
+                    ref_sector_centroids_y = scipy.interpolate.InterpolatedUnivariateSpline(
                         numpy.flip(ref_sector_centroids[:,2]),
                         numpy.flip(ref_sector_centroids[:,1]),
                         k=1,
@@ -407,7 +395,7 @@ def compute_strains(
                 if (r < 15.): continue
                 # if (ll < 1./3): continue
                 twist_vs_height_file.write(" ".join([str(val) for val in [temporal_offset+k_frame*temporal_resolution, ll, beta]]) + "\n")
-            mesh_filename = working_folder+"/"+working_basename+("-wStrains")*(not in_place)+"_"+str(k_frame).zfill(working_zfill)+"."+working_ext
+            mesh_filename = working_folder+"/"+working_basename+("-wStrains")*(not in_place)+"_"+str(k_frame).zfill(working_series.zfill)+"."+working_ext
             myvtk.writeUGrid(
                 ugrid=mesh,
                 filename=mesh_filename,
