@@ -2,26 +2,15 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
-import dolfin
-import glob
 import math
 import numpy
-import os
 import random
-import vtk
-
-import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
-
-import dolfin_warp as dwarp
 
 ################################################################################
 
@@ -125,7 +114,7 @@ class Image():
         else:
             assert (0), "texture type must be \"no\", \"tagging\", \"taggX\", \"taggY\" or \"taggZ\". Aborting."
 
-        # noise
+        # noise (MG20220818: Should use dwarp.Noise)
         if (noise["type"] == "no"):
             self.I0_noise = self.I0_noise_no_wGrad if (generate_image_gradient) else self.I0_noise_no
         elif (noise["type"] == "normal"):
